#!/usr/bin/env python
'''
    This will import data from some srpms
'''

import os
import sys
import rpm

from updateinfo.updateinfohelper import UpdateinfoHelper

class MakeUpdateinfo(UpdateinfoHelper):
    '''
        This is the class doing all the work
    '''
    def __init__(self, configfile, verbose=False):
        UpdateinfoHelper.__init__(self, configfile)


        self.build(verbose=verbose)

        self.unknown_packages.sort()
        for i in self.unknown_packages:
            print i

    def updateid_from_package(self, package):
        '''
            Given a package name, what is its update id?
        '''
        _fd = os.open(package, os.O_RDONLY)
        _ts = rpm.TransactionSet()
        bin_hdr = _ts.hdrFromFdno(_fd)
        os.close(_fd)

        if self.hdr[rpm.RPMTAG_SOURCERPM]:
            srpm_filename = self.hdr[rpm.RPMTAG_SOURCERPM]
            _fd = os.open(self.config['datastore']['srpm_dir'] + '/' + srpm_filename)
            _ts = rpm.TransactionSet()
            hdr = _ts.hdrFromFdno(_fd)
            os.close(_fd)
            srpm_name = hdr[rpm.RPMTAG_NAME]
        else:
            srpm_name = bin_hdr[rpm.RPMTAG_NAME]
        return (srpm_name, self.config['datastore']['my_id_prefix'] + srpm_name)


    def add_entry(self, tuv_updateid, my_updateid):
        '''
            What do we know about this update id.
            We don't care about collections, packages, or references here
             just stuff that pertains to this update

            Once you've got the data here, simply add the entry in

            Descriptions of these values can be found in the
             updateinfo.xsd
        '''
        update_from = self.config['updatefrom']
        update_status = self.config['status']
        update_type = 'newpackage'
        update_issue_date = self.config['datastore']['release_date']

        update_title = tuv_updateid

        _fd = os.open(self.config['datastore']['srpm_dir'] + '/' + tuv_updateid, os.O_RDONLY)
        _ts = rpm.TransactionSet()
        hdr = _ts.hdrFromFdno(_fd)
        update_description = hdr[rpm.RPMTAG_DESCRIPTION]

        update_severity = None

        update_modifcation_date = None
        update_summary = None
        update_rights = None
        update_solution = None

        update_reboot = False
        update_restart = False
        update_relogin = False

        self._add_entry(my_updateid, update_from, update_status, update_type,
                       update_title, update_issue_date, update_modifcation_date,
                       update_description, update_summary, update_rights,
                       update_solution, update_severity, update_reboot,
                       update_restart, update_relogin)

    def add_references(self, tuv_updateid, my_updateid):
        '''
            What references are attached to this update?
             Find them and add them in
        '''
        return None


#############################################################################
if __name__ == "__main__":
    import optparse
    OPTPARSER = optparse.OptionParser()
    OPTPARSER.add_option('--configfile', help='''What File''')
    OPTPARSER.add_option('--verbose', action='store_true', help='''Be chatty''')
    OPTIONS = OPTPARSER.parse_args()[0]

    if OPTIONS.configfile == None:
        OPTPARSER.print_help()
        print '\nMissing arg --configfile'
        sys.exit(1)

    MakeUpdateinfo(OPTIONS.configfile, OPTIONS.verbose)

